@@ -14,4 +14,9 @@
     You should have received a copy of the GNU General Public License
     along with PM4Py.  If not, see <https://www.gnu.org/licenses/>.
 '''
+
+import warnings
+
+warnings.warn("pm4py.objects.log.util.general will be removed in a future version")
+
 from pm4py.util.constants import CASE_ATTRIBUTE_GLUE, CASE_ATTRIBUTE_PREFIX, PARAMETER_KEY_CASE_ATTRIBUTE_PRFIX, PARAMETER_KEY_CASE_GLUE
